@@ -2,7 +2,7 @@
 /**
  * functions used by and for querywindow
  *
- * @version $Id: querywindow.js 10205 2007-03-26 14:50:14Z cybot_tm $
+ * @version $Id: querywindow.js 11402 2008-07-15 18:42:50Z lem9 $
  */
 
 /**
@@ -75,6 +75,7 @@ function setTable(new_table) {
  *
  * @uses 	goTo()
  * @uses 	opendb_url
+ * @uses 	token
  * @uses 	db
  * @uses 	server
  * @uses 	table
@@ -92,6 +93,7 @@ function refreshMain(url) {
         }
     }
     goTo(url + '?server=' + encodeURIComponent(server) +
+        '&token=' + encodeURIComponent(token) +
         '&db=' + encodeURIComponent(db) +
         '&table=' + encodeURIComponent(table) +
         '&lang=' + encodeURIComponent(lang) +
@@ -103,6 +105,7 @@ function refreshMain(url) {
  * reloads navigation frame
  *
  * @uses 	goTo()
+ * @uses 	token
  * @uses 	db
  * @uses 	server
  * @uses 	table
@@ -112,6 +115,7 @@ function refreshMain(url) {
  */
 function refreshNavigation() {
     goTo('navigation.php?server=' + encodeURIComponent(server) +
+        '&token=' + encodeURIComponent(token)  +
         '&db=' + encodeURIComponent(db)  +
         '&table=' + encodeURIComponent(table) +
         '&lang=' + encodeURIComponent(lang) +
@@ -185,8 +189,8 @@ function markDbTable(db, table)
 /**
  * sets current selected server, table and db (called from libraries/footer.inc.php)
  */
-function setAll( new_lang, new_collation_connection, new_server, new_db, new_table ) {
-    //alert('setAll( ' + new_lang + ', ' + new_collation_connection + ', ' + new_server + ', ' + new_db + ', ' + new_table + ' )');
+function setAll( new_lang, new_collation_connection, new_server, new_db, new_table, new_token ) {
+    //alert('setAll( ' + new_lang + ', ' + new_collation_connection + ', ' + new_server + ', ' + new_db + ', ' + new_table + ', ' + new_token + ' )');
     if (new_server != server || new_lang != lang
       || new_collation_connection != collation_connection) {
         // something important has changed
@@ -195,6 +199,7 @@ function setAll( new_lang, new_collation_connection, new_server, new_db, new_tab
         table  = new_table;
         collation_connection  = new_collation_connection;
         lang  = new_lang;
+        token  = new_token;
         refreshNavigation();
     } else if (new_db != db || new_table != table) {
         // save new db and table
