@@ -1,5 +1,5 @@
 <?php
-/* $Id: swedish-utf-8.inc.php 10439 2007-06-15 17:13:29Z lem9 $ */
+/* $Id: swedish-utf-8.inc.php 11186 2008-04-05 14:39:19Z lem9 $ */
 
 /*
  * Translated by Björn T. Hallberg <bjornth at users.sourceforge.net>
@@ -7,7 +7,6 @@
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
-$allow_recoding = TRUE;
 $text_dir = 'ltr';
 $number_thousands_separator = ' ';
 $number_decimal_separator = ',';
@@ -22,9 +21,9 @@ $datefmt = '%d %B %Y kl %H:%M';
 $timespanfmt = '%s dagar, %s timmar, %s minuter och %s sekunder';
 
 $strAbortedClients = 'Avbrutna';
-$strAccessDenied = 'Åtkomst nekad';
 $strAccessDeniedCreateConfig = 'Trolig orsak till detta är att du inte skapade en konfigurationsfil. Du vill kanske använda %1$suppsättningsskript%2$s för att skapa en.';
 $strAccessDeniedExplanation = 'phpMyAdmin försökte skapa en förbindelse till MySQL-servern, men servern nekade uppkopplingen. Kontrollera värd, användarnamn och lösenord i config.inc.php och förvissa dig om att de stämmer överens med informationen från administratören av MySQL-servern.';
+$strAccessDenied = 'Åtkomst nekad';
 $strAction = 'Åtgärd';
 $strAddAutoIncrement = 'Lägg till AUTO_INCREMENT-värde';
 $strAddClause = 'Lägg till %s';
@@ -119,7 +118,6 @@ $strCardinality = 'Kardinalitet';
 $strCaseInsensitive = 'skiftlägesokänsligt';
 $strCaseSensitive = 'skiftlägeskänsligt';
 $strCentralEuropean = 'Centraleuropeisk';
-$strChange = 'Ändra';
 $strChangeCopyModeCopy = '... behåll den gamla.';
 $strChangeCopyModeDeleteAndReload = ' ... ta bort den gamla från användartabellerna och ladda om privilegierna efteråt.';
 $strChangeCopyModeJustDelete = ' ... ta bort den gamla från användartabellerna.';
@@ -127,6 +125,7 @@ $strChangeCopyModeRevoke = ' ... upphäv alla aktiva privilegier från dan gamla
 $strChangeCopyMode = 'Skapa en ny användare med samma privilegier och ...';
 $strChangeCopyUser = 'Ändra inloggningsinformation / Kopiera användare';
 $strChangeDisplay = 'Välj fält som ska visas';
+$strChange = 'Ändra';
 $strChangePassword = 'Byt lösenord';
 $strCharsetOfFile = 'Filens teckenuppsättning:';
 $strCharsetsAndCollations = 'Teckenuppsättningar och kollationeringar';
@@ -156,6 +155,7 @@ $strConnectionError = 'Kan ej skapa förbindelse: ogiltiga inställningar.';
 $strConnections = 'Uppkopplingar';
 $strConstraintsForDumped = 'Restriktioner för dumpade tabeller';
 $strConstraintsForTable = 'Restriktioner för tabell';
+$strControluserFailed = 'Uppkoppling för controluser enligt din konfiguration misslyckades.';
 $strCookiesRequired = 'Kakor (cookies) måste tillåtas för att gå vidare.';
 $strCopyDatabaseOK = 'Databas %s har kopierats till %s';
 $strCopy = 'Kopiera';
@@ -181,8 +181,6 @@ $strCreationDates = 'Skapad/Uppdaterad/Kontrollerad datum';
 $strCriteria = 'Villkor';
 $strCroatian = 'Kroatisk';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'CSV-alternativ';
-$strCSVOptions = 'CSV-alternativ';
 $strCyrillic = 'Kyrillisk';
 $strCzechSlovak = 'Tjeckisk-Slovakisk';
 $strCzech = 'Tjeckisk';
@@ -237,7 +235,6 @@ $strDisplayOrder = 'Visningsordning:';
 $strDisplayPDF = 'Visa PDF-schema';
 $strDoAQuery = 'Utför en "Query By Example" (jokertecken: "%")';
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'DocSQL-alternativ';
 $strDocu = 'Dokumentation';
 $strDoYouReally = 'Vill du verkligen ';
 $strDropDatabaseStrongWarning = 'Du håller på att FÖRGÖRA en hel databas!';
@@ -264,7 +261,7 @@ $strEngineDisabled = '%s har inaktiverats på denna MySQL-server.';
 $strEngines = 'Motorer';
 $strEngineUnsupported = 'Denna MySQL-server har inte stöd för lagringsmotorn %s.';
 $strEnglish = 'Engelsk';
-$strEnglishPrivileges = ' Obs! MySQL-privilegiumnamn anges på engelska ';
+$strEnglishPrivileges = ' Obs! MySQL privilegiumnamn anges på engelska ';
 $strError = 'Fel';
 $strErrorInZipFile = 'Fel i ZIP-arkiv:';
 $strErrorRelationAdded = 'Fel: Relation inte tillagd.';
@@ -274,8 +271,8 @@ $strErrorSaveTable = 'Fel vid sparande av koordinater för Designer.';
 $strEscapeWildcards = 'Jokerteknen _ och % måste föregås av ett \ för att användas i egentlig betydelse';
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estnisk';
+$strEvent = 'Händelse';
 $strExcelEdition = 'Excel-version';
-$strExcelOptions = 'Excel-alternativ';
 $strExecuteBookmarked = 'Utför bokmärkt fråga';
 $strExplain = 'Förklara SQL-kod';
 $strExport = 'Exportera';
@@ -287,7 +284,7 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Misslyckade försök';
 $strField = 'Fält';
 $strFieldHasBeenDropped = 'Fältet %s har tagits bort';
-$strFieldsEmpty = ' Antalet fält är noll! ';
+$strFieldInsertFromFileTempDirNotExists = 'Fel vid flytt av uppladdad fil, se FAQ 1.11';
 $strFieldsEnclosedBy = 'Fälten omges av';
 $strFieldsEscapedBy = 'Specialtecken i fält föregås av';
 $strFields = 'Fält';
@@ -300,6 +297,7 @@ $strFileNameTemplateDescriptionServer = 'servernamn';
 $strFileNameTemplateDescriptionTable = 'tabellnamn';
 $strFileNameTemplate = 'Mall för filnamn';
 $strFileNameTemplateRemember = 'kom ihåg mall';
+$strFiles = 'Filer';
 $strFileToImport = 'Fil att importera';
 $strFixed = 'fast';
 $strFlushPrivilegesNote = 'Anm: phpMyAdmin hämtar användarnas privilegier direkt från MySQL:s privilegiumtabeller. Innehållet i dessa tabeller kan skilja sig från privilegierna som servern använder ifall manuella ändringar har gjorts. I detta fall bör du %sladda om privilegierna%s innan du fortsätter.';
@@ -336,7 +334,7 @@ $strHasBeenCreated = 'har skapats.';
 $strHaveToShow = 'Du måste välja minst en kolumn som ska visas';
 $strHebrew = 'Hebreisk';
 $strHelp = 'Hjälp';
-$strHexForBinary = 'Använd hexadecimalt för binära fält';
+$strHexForBLOB = 'Använd hexadecimal för BLOB';
 $strHide = 'Dölj';
 $strHideShowAll = 'Dölj/visa alla';
 $strHideShowNoRelation = 'Dölj/visa tabeller utan relationer';
@@ -345,9 +343,7 @@ $strHomepageOfficial = 'phpMyAdmin:s officiella hemsida';
 $strHostEmpty = 'Värdnamnet är tomt!';
 $strHost = 'Värd';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 exportalternativ';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 exportalternativ';
 $strHungarian = 'Ungersk';
 
 $strIcelandic = 'Isländska';
@@ -363,14 +359,12 @@ $strImportFormat = 'Format på importerad fil';
 $strImport = 'Importera';
 $strImportSuccessfullyFinished = 'Importen har avslutats korrekt, %d frågor utförda.';
 $strIndexes = 'Index';
+$strIndexesSeemEqual = 'Följande index verkar vara lika och ett av dem bör tas bort:';
 $strIndexHasBeenDropped = 'Index %s har tagits bort';
 $strIndex = 'Index';
 $strIndexName = 'Indexnamn&nbsp;:';
 $strIndexType = 'Indextyp&nbsp;:';
-$strIndexWarningMultiple = 'Mer än en %s-nyckel skapades för kolumn `%s`';
-$strIndexWarningPrimary = 'PRIMARY- och INDEX-nycklar skall inte båda sättas för kolumn `%s`';
 $strIndexWarningTable = 'Problem med index för tabell `%s`';
-$strIndexWarningUnique = 'UNIQUE- och INDEX-nycklar skall inte båda sättas för kolumn `%s`';
 $strInnoDBAutoextendIncrement = 'Automatisk utökningsstorlek';
 $strInnoDBAutoextendIncrementDesc = 'Tillökningsstorleken vid automatisk utökning av tabellutrymme när det blir fullt.';
 $strInnoDBBufferPoolSize = 'Buffertstorlek';
@@ -429,11 +423,9 @@ $strLatexContinued = '(fortsättning)';
 $strLatexIncludeCaption = 'Inkludera tabellrubrik';
 $strLatexLabel = 'Etikett';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX-alternativ';
 $strLatexStructure = 'Struktur för tabell __TABLE__';
 $strLatvian = 'Lettiska';
 $strLDI = 'CSV mha LOAD DATA';
-$strLDIImportOptions = 'Alternativ för CSV-import mha LOAD DATA';
 $strLDILocal = 'Använd nyckelordet LOCAL';
 $strLengthSet = 'Längd/Värden*';
 $strLimitNumRows = 'Rader per sida';
@@ -468,8 +460,8 @@ $strMIME_transformation = 'Webbläsaromvandling';
 $strMIMETypesForTable = 'MIME-TYPER FÖR TABELL';
 $strMIME_without = 'Kursiverade MIME-typer har inte någon separat omvandlingsfunktion';
 $strModifications = 'Ändringarna har sparats';
-$strModify = 'Ändra';
 $strModifyIndexTopic = 'Ändra ett index';
+$strModify = 'Ändra';
 $strMoveMenu = 'Flytta meny';
 $strMoveTable = 'Flytta tabellen till (databas<b>.</b>tabell):';
 $strMoveTableOK = 'Tabellen %s har flyttats till %s.';
@@ -490,10 +482,11 @@ $strMyISAMSortBufferSize = 'Storlek för sorteringsbuffert';
 $strMySQLCharset = 'MySQL teckenuppsättning';
 $strMysqlClientVersion = 'MySQL klientversion';
 $strMySQLConnectionCollation = 'Kollation för MySQL-uppkoppling';
+$strMysqlLibDiffersServerVersion = 'Din PHP MySQL bibliotekversion %s skiljer sig från din MySQL serverversion %s. Detta kan orsaka oförutsägbara beteenden.';
 $strMySQLSaid = 'MySQL sa: ';
 $strMySQLShowProcess = 'Visa processer';
-$strMySQLShowStatus = 'Visa MySQL-körningsinformation';
-$strMySQLShowVars = 'Visa MySQL:s systemvariabler';
+$strMySQLShowStatus = 'Visa MySQL körningsinformation';
+$strMySQLShowVars = 'Visa MySQL systemvariabler';
 
 $strName = 'Namn';
 $strNext = 'Nästa';
@@ -536,13 +529,12 @@ $strNumTables = 'Tabeller';
 
 $strOK = 'OK';
 $strOpenDocumentSpreadsheet = 'OpenDocument-kalkylblad';
-$strOpenDocumentSpreadsheetOptions = 'OpenDocument-kalkylbladsalternativ';
 $strOpenDocumentText = 'OpenDocument-text';
-$strOpenDocumentTextOptions = 'OpenDocument-textalternativ';
 $strOpenNewWindow = 'Öppna nytt phpMyAdmin-fönster';
 $strOperations = 'Operationer';
 $strOperator = 'Operator';
 $strOptimizeTable = 'Optimera tabell';
+$strOptions = 'Alternativ';
 $strOr = 'Eller';
 $strOverhead = 'Outnyttjat';
 $strOverwriteExisting = 'Skriv över befintlig fil(er)';
@@ -560,7 +552,6 @@ $strPasswordNotSame = 'Lösenorden är inte lika!';
 $strPdfDbSchema = 'Schema för databasen "%s" - Sidan %s';
 $strPdfInvalidTblName = 'Tabellen "%s" finns inte!';
 $strPdfNoTables = 'Inga tabeller';
-$strPDFOptions = 'PDF-alternativ';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Skapar en rapport som innehåller data från en enstaka tabell)';
 $strPDFReportTitle = 'Rapportrubrik';
@@ -628,6 +619,7 @@ $strPrivilegesReloaded = 'Privilegierna har laddats om.';
 $strProcedures = 'Procedurer';
 $strProcesses = 'Processer';
 $strProcesslist = 'Processlista';
+$strProfiling = 'Under produktion';
 $strProtocolVersion = 'Protokollversion';
 $strPutColNames = 'Ange fältnamn på första raden';
 
@@ -669,12 +661,15 @@ $strReplaceTable = 'Ersätt data i tabell';
 $strReplication = 'Replikering';
 $strReset = 'Nollställ';
 $strResourceLimits = 'Resursbegränsningar';
+$strRestartInsertion = 'Börja om infogning med %s rader';
 $strReType = 'Skriv igen';
 $strRevokeAndDeleteDescr = 'Användarna kommer fortfarande ha kvar privilegiet USAGE tills privilegierna laddas om.';
 $strRevokeAndDelete = 'Upphäv användarnas alla aktiva privilegier och ta bort användarna efteråt.';
 $strRevokeMessage = 'Du har upphävt privilegierna för %s';
 $strRevoke = 'Upphäv';
 $strRomanian = 'Rumänska';
+$strRoutineReturnType = 'Returtyp';
+$strRoutines = 'Rutiner';
 $strRowLength = 'Radlängd';
 $strRowsFrom = 'rader med början från';
 $strRowSize = 'Radstorlek';
@@ -726,6 +721,7 @@ $strServerTabVariables = 'Variabler';
 $strServerTrafficNotes = '<b>Servertrafik</b>: Dessa tabeller visar statistik för nätverkstrafiken hos denna MySQL-server sedan den startade.';
 $strServerVars = 'Servervariabler och inställningar';
 $strServerVersion = 'Serverversion';
+$strSessionStartupErrorGeneral = 'Kan inte starta session utan fel. Kontrollera felmeddelanden i din PHP:s och/eller webbservers loggfil och konfigurera din PHP-installation korrekt.';
 $strSessionValue = 'Sessionsvärde';
 $strSetEnumVal = 'Om en fälttyp är "enum" eller "set", ange värden enligt följande format: \'a\',\'b\',\'c\'...<br />Om du behöver lägga till ett bakåtstreck ("\") eller ett enkelcitat ("\'") i värdena, skriv ett bakåtstreck före tecknet (t.ex. \'\\\\xyz\' eller \'a\\\'b\').';
 $strShowAll = 'Visa alla';
@@ -870,8 +866,6 @@ $strSpanish = 'Spanska';
 $strSplitWordsWithSpace = 'Ord separeras med mellanslag (" ").';
 $strSQLCompatibility = 'SQL-kompatibilitet';
 $strSQLExportType = 'Export-typ';
-$strSQLImportOptions = 'SQL-alternativ';
-$strSQLOptions = 'SQL-alternativ';
 $strSQLParserBugMessage = 'Det är möjligt att du har hittat en bugg i SQL-analysatorn. Var god granska din fråga noga och kontrollera att citationstecknen är korrekta och matchar varandra. En annan möjlig felorsak kan vara att du överför en fil med binärkod som inte ligger inom citationstecken. Du kan även testa din fråga i MySQL:s kommandoradsgränssnitt. Felmeddelandet från MySQL-servern nedan, om det finns något, kan också hjälpa dig att analysera problemet. Om du fortfarande har problem eller om SQL-analysatorn misslyckas när kommandoradsgränssnittet lyckas, var vänlig reducera din inmatning av SQL-frågor till den enda fråga som orsakar problem och skicka en buggrapport med datastycket i URKLIPP-sektionen nedan:';
 $strSQLParserUserError = 'Det verkar vara ett fel i din SQL-fråga. Felmeddelandet från MySQL-servern nedan, om det finns något, kan också hjälpa dig att analysera problemet.';
 $strSQLQuery = 'SQL-fråga';
@@ -893,13 +887,13 @@ $strStrucCSV = 'CSV';
 $strStrucData = 'Struktur och data';
 $strStrucExcelCSV = 'CSV för MS Excel';
 $strStrucNativeExcel = 'Naturlig MS Excel-data';
-$strStrucNativeExcelOptions = 'Ursprunglig Excel exportalternativ';
 $strStrucOnly = 'Enbart struktur';
 $strStructPropose = 'Föreslå tabellstruktur';
 $strStructureForView = 'Struktur för visning';
 $strStructure = 'Struktur';
 $strSubmit = 'Sänd';
 $strSuccess = 'Din SQL-fråga utfördes korrekt';
+$strSuhosin = 'Server körs med Suhosin. Se %sdokumentation%s för möjliga frågor.';
 $strSum = 'Summa';
 $strSwedish = 'Svensk';
 $strSwitchToDatabase = 'Byt till kopierad databas';
@@ -934,7 +928,7 @@ $strThisHost = 'Denna värd';
 $strThreads = 'Trådar';
 $strThreadSuccessfullyKilled = 'Tråd %s dödades med framgång.';
 $strTimeoutInfo = 'Tidsbegränsningen överskreds vid föregående import. Efter återupptagning av importen kommer den fortsätta från position %d.';
-$strTimeoutNothingParsed = 'Dock blev inga data bearbetade i senaste körningen. Detta betyder vanligtvis att phpMyAdmin inte kan slutföra denna import såvida du inte ökar php:s tidsbegränsningar.';
+$strTimeoutNothingParsed = 'Dock blev inga data bearbetade i senaste körningen. Detta betyder vanligtvis att phpMyAdmin inte kan slutföra denna import såvida du inte ökar PHP:s tidsbegränsningar.';
 $strTimeoutPassed = 'Skriptets tidsbegränsning har överskridits. Om du vill slutföra importen, importera samma fil igen så kommer importen att återupptas.';
 $strTime = 'Tid';
 $strToFromPage = 'till/från sida';
@@ -959,6 +953,7 @@ $strTransformation_text_plain__imagelink = 'Visar en bild och en länk; fältet
 $strTransformation_text_plain__link = 'Visar en länk; fältet innehåller filnamnet. Första parametern är ett URL-prefix såsom "http://www.example.com/". Andra parametern är en titel för länken.';
 $strTransformation_text_plain__sql = 'Formaterar text som en SQL-fråga med markerade satser.';
 $strTransformation_text_plain__substr = 'Visar del av en sträng. Första parametern är antalet tecken att hoppa över från början på strängen (standardvärde: 0). Andra parametern är antalet tecken som ska returneras (standardvärde: till slutet på strängen). Den tredje parametern är en sträng som läggs till i slutet och/eller början när trunkering utförs (standardvärde: "...").';
+$strTriggers = 'Utlösare';
 $strTruncateQueries = 'Korta av visade frågor';
 $strTurkish = 'Turkisk';
 $strType = 'Typ';
@@ -975,6 +970,13 @@ $strUpdateProfileMessage = 'Profilen har uppdaterats.';
 $strUpdateQuery = 'Uppdatera fråga';
 $strUpdComTab = 'Se dokumentationen för uppdatering av din tabell column_comments';
 $strUpgrade = 'Du bör uppgradera till %s %s eller senare.';
+$strUploadErrorCantWrite = 'Misslyckades att skriva fil till disk.';
+$strUploadErrorExtension = 'Filuppladdning stoppades av tillägg.';
+$strUploadErrorFormSize = 'Den uppladdade filen överskrider direktivet MAX_FILE_SIZE som specificerades i HTML-formuläret.';
+$strUploadErrorIniSize = 'Den uppladdade filen överskrider direktivet upload_max_filesize i php.ini.';
+$strUploadErrorNoTempDir = 'Saknar en temporär katalog.';
+$strUploadErrorPartial = 'Den uppladdade filen var endast delvis uplladdad.';
+$strUploadErrorUnknown = 'Okänt fel i filuppladdning.';
 $strUploadLimit = 'Du försökte förmodligen ladda upp en för stor fil. Se %sdokumentationen%s för metoder att gå runt denna begränsning.';
 $strUploadsNotAllowed = 'Filuppladdningar är inte tillåtna på denna server.';
 $strUsage = 'Användning';
@@ -1004,6 +1006,7 @@ $strViewDumpDB = 'Visa SQL-satser för databasen';
 $strViewDump = 'Visa SQL-satser för tabellen';
 $strViewHasBeenDropped = 'Vyn %s har tagits bort';
 $strViewMaxExactCount = 'Denna vy har mer än %s rader. Var god se %sdokumentationen%s.';
+$strViewName = 'Namn på vy';
 $strView = 'Vy';
 
 $strWebServerUploadDirectoryError = 'Katalogen som du konfigurerat för uppladdning kan inte nås';
@@ -1016,13 +1019,10 @@ $strWithChecked = 'Med markerade:';
 $strWriteRequests = 'Skrivefterfrågningar';
 $strWrongUser = 'Fel användarnamn/lösenord. Åtkomst nekad.';
 
-$strXMLOptions = 'XML-alternativ';
 $strXML = 'XML';
 
 $strYes = 'Ja';
 
 $strZeroRemovesTheLimit = 'Anm: Genom att sätta dessa alternativ till 0 (noll) tas begränsningarna bort.';
 $strZip = '"zippad"';
-
-$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
 ?>
