@@ -3,7 +3,7 @@
 /**
  *
  *
- * @version $Id: Config.class.php 10967 2007-12-08 12:46:36Z lem9 $
+ * @version $Id: Config.class.php 11445 2008-07-28 19:37:23Z lem9 $
  */
 
 /**
@@ -85,7 +85,7 @@ class PMA_Config
      */
     function checkSystem()
     {
-        $this->set('PMA_VERSION', '2.11.3');
+        $this->set('PMA_VERSION', '2.11.8.1');
         /**
          * @deprecated
          */
@@ -178,6 +178,9 @@ class PMA_Config
                    && preg_match('@Safari/([0-9]*)@', $HTTP_USER_AGENT, $log_version2)) {
             $this->set('PMA_USR_BROWSER_VER', $log_version[1] . '.' . $log_version2[1]);
             $this->set('PMA_USR_BROWSER_AGENT', 'SAFARI');
+        } elseif (preg_match('@rv:1.9(.*)Gecko@', $HTTP_USER_AGENT)) {
+            $this->set('PMA_USR_BROWSER_VER', '1.9');
+            $this->set('PMA_USR_BROWSER_AGENT', 'GECKO');
         } elseif (preg_match('@Mozilla/([0-9].[0-9]{1,2})@', $HTTP_USER_AGENT, $log_version)) {
             $this->set('PMA_USR_BROWSER_VER', $log_version[1]);
             $this->set('PMA_USR_BROWSER_AGENT', 'MOZILLA');
@@ -372,6 +375,8 @@ class PMA_Config
          * Parses the configuration file
          */
         $old_error_reporting = error_reporting(0);
+        // avoid "headers already sent" error when file contains a BOM
+        ob_start();
         if (function_exists('file_get_contents')) {
             $eval_result =
                 eval('?>' . trim(file_get_contents($this->getSource())));
@@ -379,6 +384,7 @@ class PMA_Config
             $eval_result =
                 eval('?>' . trim(implode("\n", file($this->getSource()))));
         }
+        ob_end_clean();
         error_reporting($old_error_reporting);
 
         if ($eval_result === false) {
@@ -539,12 +545,14 @@ class PMA_Config
 
     /**
      * returns a unique value to force a CSS reload if either the config
-     * or the theme changes
+     * or the theme changes;
+     * must also check the pma_fontsize cookie in case there is no
+     * config file
      * @return  int  Unix timestamp
      */
-    function getMtime()
+    function getThemeUniqueValue()
     {
-        return intval($_SESSION['PMA_Config']->get('fontsize')) + ($this->source_mtime + $this->default_source_mtime + $_SESSION['PMA_Theme']->mtime_info);
+        return intval((null !== $_SESSION['PMA_Config']->get('fontsize') ? $_SESSION['PMA_Config']->get('fontsize') : $_COOKIE['pma_fontsize'])) + ($this->source_mtime + $this->default_source_mtime + $_SESSION['PMA_Theme']->mtime_info + $_SESSION['PMA_Theme']->filesize_info);
     }
 
     /**
@@ -861,17 +869,18 @@ class PMA_Config
         if (empty($url)) {
             if (PMA_getenv('PATH_INFO')) {
                 $url = PMA_getenv('PATH_INFO');
+            // on IIS with PHP-CGI:
+            } elseif (PMA_getenv('SCRIPT_NAME')) {
+                $url = PMA_getenv('SCRIPT_NAME');
             } elseif (PMA_getenv('PHP_SELF')) {
                 // PHP_SELF in CGI often points to cgi executable, so use it
                 // as last choice
                 $url = PMA_getenv('PHP_SELF');
-            } elseif (PMA_getenv('SCRIPT_NAME')) {
-                $url = PMA_getenv('PHP_SELF');
             }
         }
 
         $parsed_url = @parse_url($_SERVER['REQUEST_URI']); // produces E_WARNING if it cannot get parsed, e.g. '/foobar:/'
-        if ($parsed_url === false) {
+        if ($parsed_url === false || empty($parsed_url['path'])) {
             $parsed_url = array('path' => $url);
         }
 
@@ -885,8 +894,9 @@ class PMA_Config
      */
     function enableBc()
     {
-        $GLOBALS['cfg']             =& $this->settings;
-        $GLOBALS['default_server']  =& $this->default_server;
+        $GLOBALS['cfg']             = $this->settings;
+        $GLOBALS['default_server']  = $this->default_server;
+        unset($this->default_server);
         $GLOBALS['collation_connection'] = $this->get('collation_connection');
         $GLOBALS['is_upload']       = $this->get('enable_upload');
         $GLOBALS['max_upload_size'] = $this->get('max_upload_size');
@@ -995,6 +1005,14 @@ class PMA_Config
     function getFontsizeSelection()
     {
         $current_size = $_SESSION['PMA_Config']->get('fontsize');
+        // for the case when there is no config file (this is supported)
+        if (empty($current_size)) {
+            if (isset($_COOKIE['pma_fontsize'])) {
+                $current_size = $_COOKIE['pma_fontsize'];
+            } else {
+                $current_size = '82%';
+            }
+        }
         $options = PMA_Config::getFontsizeOptions($current_size);
 
         $return = '<label for="select_fontsize">' . $GLOBALS['strFontSize'] . ':</label>' . "\n";
