@@ -5,15 +5,11 @@
  * Thanks to Piotr Roszatycki <d3xter at users.sourceforge.net> and
  * Dan Wilson who built this patch for the Debian package.
  *
- * @version $Id: cookie.auth.lib.php 10931 2007-11-20 12:55:14Z lem9 $
+ * @version $Id: cookie.auth.lib.php 11390 2008-07-15 14:14:09Z lem9 $
  */
 
-/**
- * @todo replace by constant
- * $coming_from_common can be set from outside with register_globals on
- */
-if (!isset($coming_from_common)) {
-   exit;
+if (! defined('PHPMYADMIN')) {
+    exit;
 }
 
 if (function_exists('mcrypt_encrypt') || PMA_dl('mcrypt')) {
@@ -71,7 +67,6 @@ if (function_exists('mcrypt_encrypt') || PMA_dl('mcrypt')) {
  * @uses    PMA_sendHeaderLocation()
  * @uses    PMA_select_language()
  * @uses    PMA_select_server()
- * @uses    PMA_VERSION
  * @uses    file_exists()
  * @uses    sprintf()
  * @uses    count()
@@ -110,8 +105,8 @@ function PMA_auth()
     // Defines the "item" image depending on text direction
     $item_img = $GLOBALS['pmaThemeImage'] . 'item_' . $GLOBALS['text_dir'] . '.png';
 
-    /* HTML header */
-    $page_title = 'phpMyAdmin ' . PMA_VERSION;
+    /* HTML header; do not show here the PMA version to improve security  */
+    $page_title = 'phpMyAdmin ';
     require './libraries/header_meta_style.inc.php';
     ?>
 <script type="text/javascript">
@@ -258,6 +253,12 @@ if (top != self) {
             echo '<div class="error">' . $error . '</div>' . "\n";
         }
     }
+    // the warning is also displayed on main page but show it also here,
+    // because on some PHP versions running on 64-bit, the blowfish library
+    // does not work and this would prevent login
+    if (defined('PMA_WARN_FOR_MCRYPT')) {
+        echo '<div class="warning">' . PMA_sanitize(sprintf($GLOBALS['strCantLoad'], 'mcrypt')) . '</div>' . "\n";
+    }
     ?>
 </div>
 <script type="text/javascript">
@@ -588,6 +589,10 @@ function PMA_auth_fails()
         // Remember where we got timeout to return on same place
         if (PMA_getenv('SCRIPT_NAME')) {
             $GLOBALS['target'] = basename(PMA_getenv('SCRIPT_NAME'));
+            // avoid "missing parameter: field" on re-entry
+            if ('tbl_alter.php' == $GLOBALS['target']) {
+                $GLOBALS['target'] = 'tbl_structure.php';
+            }
         }
     } elseif (PMA_DBI_getError()) {
         $conn_error = PMA_sanitize(PMA_DBI_getError());
